package
Version:
v0.9.1
Opens a new window with list of versions in this module.
Published: Mar 14, 2026
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func MustPbCopy[S any, D any](src *S) *D
PbToMap: convert a protobuf Message to map
if opt == nil, use default MarshalOptions:
&protojson.MarshalOptions{
UseProtoNames: true,
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.